@@ -57,6 +57,10 @@
 
 #define SIZE_DEFAULT_FONT 12
 
+int mlv_sdl_is_initialised = 0;
+Uint32 mlv_width_of_desktop = 0;
+Uint32 mlv_height_of_desktop = 0;
+
 DataMLV *MLV_data = NULL;
 void (*MLV_call_back_function_for_exit)(void*) = NULL;
 void *MLV_call_back_data = NULL;
@@ -145,6 +149,45 @@ void initialise_graphic_window(
 	MLV_actualise_window();
 }
 
+
+void initialise_sdl(){
+	if( ! mlv_sdl_is_initialised ){
+		if(
+			SDL_Init(
+				SDL_INIT_VIDEO | SDL_INIT_TIMER | SDL_INIT_AUDIO 
+	#if defined( OS_LINUX ) // SDL thread is not supported on Windows and MacOSX
+				| SDL_INIT_EVENTTHREAD  // Cette option est importante !
+									  // Elle permet de faire en sorte 
+					  // que le filtrage des évenements soit fait dés 
+					  // réception d'un evenement de la part de l'OS
+					  // Si cette option n'est pas activée, le filtre 
+					  // d'evenement est applique seulement après un 
+					  // appel à poll_event. Dans ce cas la gestion
+					  // de l'arret automatique du programme après 
+					  // utilisation de la croix des fenetre ne 
+					  // fonctione plus correctement. En effet, si 
+					  // l'utilisateur n'utilise pas de fonction mettant
+					  // en jeu des évènement, le filtre n'est jamais
+					  // appelé et le mécanisme d'arret automatique 
+					  // non plus.
+	#endif
+			) <0 
+		){
+			printf("Unable to init SDL: %s\n", SDL_GetError());
+			exit(1);
+		}
+	}
+}
+
+void initialise_size_of_desktop(){
+	initialise_sdl();
+	if( mlv_width_of_desktop==0 || mlv_height_of_desktop==0 ){
+		const SDL_VideoInfo* info = SDL_GetVideoInfo();	
+		mlv_width_of_desktop = info->current_w;
+		mlv_height_of_desktop = info->current_h;
+	}
+}
+
 void MLV_create_window_with_default_font(
 	const char* window_name, const char* icone_name, 
 	unsigned int width, unsigned int height,
@@ -164,30 +207,12 @@ void MLV_create_window_with_default_font(
 	/* Initialisation de la libriaire SDL pour l'uilisation de la video et du */
 	/*   temps                                                                */
 	/**************************************************************************/
-	if(
-		SDL_Init(
-			SDL_INIT_VIDEO | SDL_INIT_TIMER | SDL_INIT_AUDIO 
-#if defined( OS_LINUX ) // SDL thread is not supported on Windows and MacOSX
-			| SDL_INIT_EVENTTHREAD  // Cette option est importante !
-			                      // Elle permet de faire en sorte 
-			      // que le filtrage des évenements soit fait dés 
-			      // réception d'un evenement de la part de l'OS
-			      // Si cette option n'est pas activée, le filtre 
-			      // d'evenement est applique seulement après un 
-			      // appel à poll_event. Dans ce cas la gestion
-			      // de l'arret automatique du programme après 
-			      // utilisation de la croix des fenetre ne 
-			      // fonctione plus correctement. En effet, si 
-			      // l'utilisateur n'utilise pas de fonction mettant
-			      // en jeu des évènement, le filtre n'est jamais
-			      // appelé et le mécanisme d'arret automatique 
-			      // non plus.
-#endif
-		) <0 
-	){
-		printf("Unable to init SDL: %s\n", SDL_GetError());
-		exit(1);
-	}
+	initialise_sdl();
+
+	/**************************************************************************/
+	/* Save the size of the desktop                                           */
+	/**************************************************************************/
+	initialise_size_of_desktop();
 
 	/**************************************************************************/
 	/* Creation d'un fenetre graphique                                        */
@@ -250,6 +275,25 @@ void MLV_enable_full_screen(){
 	initialise_graphic_window( MLV_data->width, MLV_data->height, 1 );
 }
 
+void MLV_create_full_screen_window(
+	const char* window_name, const char* icone_name,
+	unsigned int width, unsigned int height
+){
+	MLV_create_window( window_name, icone_name, width, height );
+	MLV_enable_full_screen();
+}
+
+void MLV_create_full_screen_window_with_default_font(
+	const char* window_name, const char* icone_name, 
+	unsigned int width, unsigned int height,
+	const char* path_to_font, unsigned int size_font
+){
+	MLV_create_window_with_default_font(
+		window_name, icone_name, width, height, path_to_font, size_font
+	);
+	MLV_enable_full_screen();
+}
+
 void MLV_disable_full_screen(){
 	initialise_graphic_window( MLV_data->width, MLV_data->height, 0 );
 }
@@ -281,6 +325,12 @@ int MLV_get_window_width(){
 	return MLV_data->width;
 }
 
+void MLV_clear_window( MLV_Color color ){
+	MLV_draw_filled_rectangle(
+		0, 0, MLV_get_window_width( ), MLV_get_window_height( ), color
+	);
+}
+
 void MLV_free_window(){
 	if( ! MLV_data ){
 		ERROR("No window has been created.");
@@ -313,4 +363,18 @@ void MLV_execute_at_exit( void (*function)(void*), void* data ){
 	MLV_call_back_data = data;
 }
 
+void MLV_get_desktop_size( unsigned int* width, unsigned int* height ){
+	initialise_size_of_desktop();
+	*width = mlv_width_of_desktop;
+	*height = mlv_height_of_desktop;
+}
 
+int MLV_get_desktop_height( ){
+	initialise_size_of_desktop();
+	return mlv_height_of_desktop;
+}
+
+int MLV_get_desktop_width( ){
+	initialise_size_of_desktop();
+	return mlv_width_of_desktop;
+}
